<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Lengthen</name>
    <message>
        <location filename="../Lengthen.js" line="+60"/>
        <source>Choose line or arc</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Proszę wskazać linię lub łuk</translation>
    </message>
    <message>
        <location filename="../Lengthen.ui" line="+17"/>
        <source>Amount:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wartość:</translatorcomment>
        <translation>Wartość:</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Amount to lengthen or shorten (negative)</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Określa wartość wydłużenia lub skrócenia (ujemna)</translation>
    </message>
    <message>
        <location filename="../LengthenInit.js" line="+2"/>
        <source>&amp;Lengthen / Shorten</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>&amp;Wydłuż / skróć</translation>
    </message>
</context>
</TS>
